@@ -1,14 +1,14 @@
 # bagging {ipred}
 # 
 
-SL.ipredbagg <- function(Y, X, newX, family, nbagg = 100, control = rpart.control(xval = 0, maxsurrogate = 0, minsplit = 20, cp = 0.01, maxdepth = 30), ...){
+SL.ipredbagg <- function(Y, X, newX, family, nbagg = 100, control = rpart::rpart.control(xval = 0, maxsurrogate = 0, minsplit = 20, cp = 0.01, maxdepth = 30), ...){
 	.SL.require('ipred')
 	if(family$family == "gaussian"){
-		fit.bag <- ipredbagg(y=Y, X = X, nbagg = nbagg, control = control)
+		fit.bag <- ipred::ipredbagg(y=Y, X = X, nbagg = nbagg, control = control)
 		pred <- predict(fit.bag, newdata = newX, aggregation = "average")
 	}
 	if(family$family == "binomial"){
-		fit.bag <- ipredbagg(y = as.factor(Y), X = X, nbagg = nbagg, control = control)
+		fit.bag <- ipred::ipredbagg(y = as.factor(Y), X = X, nbagg = nbagg, control = control)
 		pred <- predict(fit.bag, newdata = newX, type = "prob", aggregation = "average")[, 2]
 	}
 	fit <- list(object = fit.bag)
